%global momorel 1

Summary:	A high-performance implementation of MPI
Name:		mpich2
Version:	1.1
Release:	%{momorel}m%{?dist}
License:	MIT
Group:		Development/Libraries
URL:		http://www.mcs.anl.gov/research/projects/mpich2
Source:		http://www.mcs.anl.gov/research/projects/mpich2/downloads/tarballs/%{version}/%{name}-%{version}.tar.gz
NoSource:	0
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires:	libXt-devel, e2fsprogs-devel
BuildRequires:	java-devel-openjdk, gcc-gfortran
BuildRequires:	emacs-common, perl, python
Requires:	%{name}-libs = %{version}-%{release}
Requires:	python
Requires(post):	chkconfig
Requires(preun):chkconfig
Obsoletes:	mpich2-doc

%description
MPICH2 is a high-performance and widely portable implementation of the
MPI standard. This release has all MPI-2.1 functions and features
required by the standard with the exeption of support for the
"external32" portable I/O format.

The mpich2 binaries in Momonga were configured to use the default
process manager 'MPD' using the default device 'ch3'. The ch3 device
was configured with support for the nemesis channel that allows for
shared-memory and TCP/IP sockets based communication.

The Momonga builds also include support for using '/usr/sbin/alternatives'
and/or the 'module environment' to select which MPI implementation to use
when multiple implementations are installed.

%package devel
Summary:	Development files for mpich2
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	pkgconfig
Requires:	gcc-gfortran
Requires(post):	chkconfig
Requires(preun): chkconfig
Requires(posttrans): chkconfig

%description devel
Contains development headers and libraries for mpich2

%package libs
Summary:	Libraries and configuration files for mpich2
Group:		Development/Libraries

%description libs
Contains the arch dependent libraries and their build configuration for mpich2

# We only compile with gcc, but other people may want other compilers.
# Set the compiler here.
%{!?opt_cc: %global opt_cc gcc}
%{!?opt_fc: %global opt_fc gfortran}
# Optional CFLAGS to use with the specific compiler...gcc doesn't need any,
# so uncomment and undefine to NOT use
%{!?opt_cc_cflags: %global opt_cc_cflags %{optflags}}
%{!?opt_fc_fflags: %global opt_fc_fflags %{optflags}}

%ifarch %{ix86} x86_64
%global selected_channels ch3:nemesis
%else
%global selected_channels ch3:sock
%endif

%ifarch x86_64 ia64 ppc64 s390x sparc64
%global mode 64
%global priority 41
%else
%global mode 32
%global priority 40
%endif

%ifarch x86_64
%global XFLAGS -fPIC
%endif

%prep
%setup -q
sed -i 's#LDFLAGS -static#LDFLAGS#' src/pm/hydra/configure

%build
%configure	\
	--enable-sharedlibs=gcc					\
	--enable-threads					\
	--with-device=%{selected_channels}			\
	--sysconfdir=%{_sysconfdir}/%{name}-%{mode}		\
	--includedir=%{_includedir}/%{name}			\
	--libdir=%{_libdir}/%{name}				\
	--datadir=%{_datadir}/%{name}				\
	--docdir=%{_docdir}/%{name}-%{version}			\
	--htmldir=%{_docdir}/%{name}-%{version}/www		\
	--with-java=%{_sysconfdir}/alternatives/java_sdk	\
	F90=%{opt_fc}						\
	F77=%{opt_fc}						\
	CFLAGS="%{?opt_cc_cflags} %{?XFLAGS}"			\
	CXXFLAGS="%{optflags} %{?XFLAGS}"			\
	F90FLAGS="%{?opt_fc_fflags} %{?XFLAGS}"			\
	FFLAGS="%{?opt_fc_fflags} %{?XFLAGS}"			\
	LDFLAGS='-Wl,-z,noexecstack'

#make %{?_smp_mflags} doesn't work
make

%install
rm -rf %{buildroot}
make DESTDIR=%{buildroot} install

## Resolve clashes with LAM/OPENMP: mpicxx mpicc mpif77 mpif90 mpiexec mpirun
rm -f %{buildroot}%{_bindir}/{mpiexec,mpirun,mpdrun}
mv %{buildroot}%{_mandir}/man1/{,mp-}mpiexec.1
pushd  %{buildroot}%{_bindir}/
ln -s mpiexec.py mpdrun
#touch mpiexec
#touch mpirun
popd
for b in mpicxx mpicc mpif77 mpif90; do 
  mv %{buildroot}%{_bindir}/$b %{buildroot}%{_bindir}/mp%{mode}-$b;
#  touch %{buildroot}%{_bindir}/$b;
  mv %{buildroot}%{_mandir}/man1/$b.1 %{buildroot}%{_mandir}/man1/mp-$b.1;
#  touch %{buildroot}%{_mandir}/man1/$b.1;
done

## Setup the executables for 'environment module'
mkdir -p %{buildroot}%{_datadir}/%{name}/bin%{mode}
for b in mpicxx mpicc mpif77 mpif90; do 
  ln -s ../../../bin/mp%{mode}-$b %{buildroot}%{_datadir}/%{name}/bin%{mode}/$b
done
for ex in mpiexec mpirun; do 
  ln -s ../../../bin/mpiexec.py %{buildroot}%{_datadir}/%{name}/bin%{mode}/$ex
done

mv %{buildroot}%{_libdir}/%{name}/pkgconfig %{buildroot}%{_libdir}/
chmod -x %{buildroot}%{_libdir}/pkgconfig/*.pc

#Install the libdir under /etc/ld.so.conf.d
mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d
echo "%{_libdir}/%{name}"	\
	> %{buildroot}%{_sysconfdir}/ld.so.conf.d/%{name}-%{_arch}.conf

# Adjust the default 'environment module' PATH for our changes
sed -i 's#bin#bin'%{mode}'#' %{buildroot}%{_datadir}/%{name}/%{name}.module


# Manually copy doc file here instead of the %files section to prevent the rpm
#build script from throwing the other things in there out
cp -pr CHANGES COPYRIGHT README RELEASE_NOTES %{buildroot}%{_docdir}/%{name}-%{version}/
cp -pr src/mpe2/README %{buildroot}%{_docdir}/%{name}-%{version}/README.mpe

# Silence rpmlint
sed -i '/^#! \//,1 d' %{buildroot}%{_sysconfdir}/%{name}-%{mode}/{mpi*.conf,mpe_help.*}

#Rename the MPI routine manpages, to avoid conflict with openmpi
for man in %{buildroot}%{_mandir}/man3/*; do
  manf=`basename $man .3`
  mv %{buildroot}%{_mandir}/man3/$manf.3 %{buildroot}%{_mandir}/man4/$manf.4
  sed s/3/4/1 -i %{buildroot}%{_mandir}/man4/$manf.4
done

# The uninstall script that is installed in this directory is not needed in rpm
# packaging 
rm -rf %{buildroot}%{_sbindir}/mpe*

find %{buildroot} -type f -name "*.la" -exec rm -f {} ';'

%clean
rm -rf %{buildroot}

%post
if [ $1 -eq 1 ] ; then
/usr/sbin/alternatives	\
	--install %{_bindir}/mpirun mpi-run %{_bindir}/mpiexec.py 41	\
	--slave	%{_bindir}/mpiexec mpi-exec %{_bindir}/mpiexec.py	\
	--slave	%{_mandir}/man1/mpiexec.1.bz2 mpi-exec-man		\
			%{_mandir}/man1/mp-mpiexec.1.bz2		\
	--slave	%{_mandir}/man1/mpif90.1.bz2 mpif90-man		\
			%{_mandir}/man1/mp-mpif90.1.bz2		\
	--slave	%{_mandir}/man1/mpif77.1.bz2 mpif77-man		\
			%{_mandir}/man1/mp-mpif77.1.bz2		\
	--slave	%{_mandir}/man1/mpicc.1.bz2 mpicc-man		\
			%{_mandir}/man1/mp-mpicc.1.bz2		\
	--slave	%{_mandir}/man1/mpic++.1.bz2 mpic++-man		\
			%{_mandir}/man1/mp-mpicxx.1.bz2
fi

%posttrans
if [ $1 -eq 0 ] ; then
/usr/sbin/alternatives	\
	--install %{_bindir}/mpirun mpi-run %{_bindir}/mpiexec.py 41	\
	--slave	%{_bindir}/mpiexec mpi-exec %{_bindir}/mpiexec.py	\
	--slave	%{_mandir}/man1/mpiexec.1.bz2 mpi-exec-man		\
			%{_mandir}/man1/mp-mpiexec.1.bz2		\
	--slave	%{_mandir}/man1/mpif90.1.bz2 mpif90-man		\
			%{_mandir}/man1/mp-mpif90.1.bz2		\
	--slave	%{_mandir}/man1/mpif77.1.bz2 mpif77-man		\
			%{_mandir}/man1/mp-mpif77.1.bz2		\
	--slave	%{_mandir}/man1/mpicc.1.bz2 mpicc-man		\
			%{_mandir}/man1/mp-mpicc.1.bz2		\
	--slave	%{_mandir}/man1/mpic++.1.bz2 mpic++-man		\
			%{_mandir}/man1/mp-mpicxx.1.bz2
fi

%preun
if [ $1 -eq 0 ] ; then
/usr/sbin/alternatives --remove mpi-run %{_bindir}/mpiexec.py
fi

%post devel
if [ $1 -eq 1 ] ; then
/usr/sbin/alternatives	\
	--install %{_bindir}/mpicc mpicc %{_bindir}/mp%{mode}-mpicc %{priority}\
	--slave	%{_bindir}/mpicxx  mpicxx  %{_bindir}/mp%{mode}-mpicxx	\
	--slave	%{_bindir}/mpif90  mpif90  %{_bindir}/mp%{mode}-mpif90	\
	--slave	%{_bindir}/mpif77  mpif77  %{_bindir}/mp%{mode}-mpif77
fi

%posttrans devel
if [ $1 -eq 0 ] ; then
/usr/sbin/alternatives	\
	--install %{_bindir}/mpicc mpicc %{_bindir}/mp%{mode}-mpicc %{priority}\
	--slave	%{_bindir}/mpicxx  mpicxx  %{_bindir}/mp%{mode}-mpicxx	\
	--slave	%{_bindir}/mpif90  mpif90  %{_bindir}/mp%{mode}-mpif90	\
	--slave	%{_bindir}/mpif77  mpif77  %{_bindir}/mp%{mode}-mpif77
fi

%preun devel
if [ $1 -eq 0 ] ; then
/usr/sbin/alternatives --remove mpicc %{_bindir}/mp%{mode}-mpicc
fi

%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%{_bindir}/*
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/bin%{mode}
%{_datadir}/%{name}/bin%{mode}/mpiexec
%{_datadir}/%{name}/bin%{mode}/mpirun
#%%exclude %{_bindir}/mpiexec
#%%exclude %{_bindir}/mpirun
%exclude %{_bindir}/*mpicc
%exclude %{_bindir}/*mpicxx
%exclude %{_bindir}/*mpif90
%exclude %{_bindir}/*mpif77
%doc %{_docdir}/%{name}-%{version}/
%{_mandir}/man1/mp-*.1*
#%%ghost %{_bindir}/mpiexec
#%%ghost %{_bindir}/mpirun
#%%ghost %{_mandir}/man1/mpi*.1*
%{_mandir}/man1/MPI.1*

%files libs
%defattr(-,root,root,-)
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*.jar
%{_libdir}/%{name}/mpe*.o
%{_libdir}/%{name}/*.so.*
%{_sysconfdir}/ld.so.conf.d/%{name}-%{_arch}.conf
%config %{_sysconfdir}/%{name}-%{mode}/

%files devel
%defattr(-,root,root,-)
%{_bindir}/mp%{mode}*
#%%ghost %{_bindir}/mpicc
#%%ghost %{_bindir}/mpicxx
#%%ghost %{_bindir}/mpif90
#%%ghost %{_bindir}/mpif77
%{_includedir}/*
%{_libdir}/%{name}/*.a
%{_libdir}/%{name}/*.so
%{_libdir}/%{name}/trace_rlog/libTraceInput.so
%{_libdir}/pkgconfig/%{name}-ch3.pc
%{_datadir}/%{name}/%{name}.module
%{_datadir}/%{name}/bin%{mode}/mpicc
%{_datadir}/%{name}/bin%{mode}/mpicxx
%{_datadir}/%{name}/bin%{mode}/mpif90
%{_datadir}/%{name}/bin%{mode}/mpif77
%{_datadir}/%{name}/examples*
%{_datadir}/%{name}/logfiles/
%{_mandir}/man4/*.4*
%doc README.testing README.romio README.developer

%changelog
* Fri Jun 26 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.1-1m)
- update to 1.1

* Wed Jun  3 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.1-0.1.2m)
- /usr/sbin/alternatives -> chkconfig

* Tue Jun  2 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.1-0.1.1m)
- nearly completely sync with Fedora devel (1.1-0.4.rc1)
- remove 0 byte ghost files

* Wed Jan 21 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.0.8-4m)
- rebuild against rpm-4.6

* Thu Jan 15 2009 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.0.8-3m)
- fix %%files to avoid conflicting

* Tue Jan 13 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.0.8-2m)
- remove trace_rlog directory
- correct installation of mpich2-ch3.pc

* Mon Jan 12 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.0.8-1m)
- update to 1.0.8
-- update Patch0 for fuzz=0
-- change URL

* Thu Apr 03 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.0.4.p1-6m)
- rebuild against gcc43

* Sat Jun 30 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.0.4.p1-5m)
- added BuildRequires: java-devel

* Sat Jun 30 2007 Masahiro Takahata <takahata@momonga-linux.org>
- (1.0.4.p1-4m)
- add rm -rf %{buildroot}/usr/lib/libTraceInput.so

* Thu Jun 28 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.0.4.p1-3m)
- add rm -rf %{buildroot}%{_libdir}/libTraceInput.so

* Tue Oct 03 2006 Masayuki SANO <nosanosa@momonga-linux.org>
- (1.0.4.p1-2m)
- fix duplications of files
- Conflicts: mpich < 1.2.6-3m

* Sat Sep 30 2006 Masayuki SANO <nosanosa@momonga-linux.org>
- (1.0.4.p1-1m)
- imported to Momonga, based on the package in Mandrake Cooker Contrib
- use alternatives to make this coexist with LAM, OpenMPI and MPICH1

* Wed Sep 06 2006 Erwan Velu <erwan@seanodes.com> 1.0.4-3mdv2007.0
- Buildrequires python (needed by mpdboot)

* Fri Aug 31 2006 Erwan Velu <erwan@seanodes.com> 1.0.4-2mdk
- The day before ulteo
- Fixing Conflicts with lam & mpich

* Mon Aug 21 2006 Erwan Velu <erwan@seanodes.com> 1.0.4-1mdk
- 1.0.4p1
- Removing patch0, merged upstream
- Removing chrpath buildrequires as cpi example is not provided under binary form
- Adding some stuff from ghuibo
- Setting f90 to gfortran

* Sun May 21 2006 Guillaume Rousse <guillomovitch@mandriva.org> 1.0.3-2mdk
- fix major in lib package name
- fix devel package provides

* Tue May 16 2006 Guillaume Rousse <guillomovitch@mandriva.org> 1.0.3-1mdk
- new version
- spec cleanup
- don't mess with /etc/bashrc, use profile.d
- use standard configure macro
- use -p for ldconfig invocation in %%post
- no more rsh requirement, as either rsh or ssh can be used
- no more user creation in %post, as it was too simplist to work, but advertise
  post-installation procedure through README.urpmi
- cleanup documentation
- no more useless shebang in configuration files
- fix summary
- fix group
- leverage versioned interdependencies
- drop useless explicit provides
- drop rpath in example
- add soname to libraries

* Sat Nov 26 2005 Thierry Vignaud <tvignaud@mandriva.com> 1.0.2-3mdk
- fix requires (#16327)

* Fri Jul 22 2005 Austin Acton <austin@mandriva.org> 1.0.2-2mdk
- fix library name
- make lib64 friendly

* Sun Jul 3 2005 Lev Givon <lev@columbia.edu> 1.0.2-1mdk
- upgrade to mpich2 1.0.2

* Mon Mar 21 2005 Antoine Ginies <aginies@n1.mandrakesoft.com> 1.0.1-2mdk
- add conflict with mpich-1.2.X
- rename mpic++ to mpi2cxx

* Fri Mar 18 2005 Antoine Ginies <aginies@n1.mandrakesoft.com> 1.0.1-1mdk
- release mpich2 1.0.1

* Fri Jul 27 2004 Erwan Velu <erwan@mandrakesoft.com> 1.2.5.2-5mdk
- Rebuild

* Fri Jun 25 2004 Erwan Velu <erwan@mandrakesoft.com> 1.2.5.2-4mdk
- Disabling java in jumpshot

* Tue Jun 15 2004 Erwan Velu <erwan@mandrakesoft.com> 1.2.5.2-3mdk
- Fixing requires

* Fri Jun 11 2004 Erwan Velu <erwan@mandrakesoft.com> 1.2.5.2-2mdk
- Fixing path for buildroot path removing
- Using a new test program
- Requires libmpich1 on mpich
* Sun Jan 04 2004 Per Oyvind Karlsen <peroyvind@linux-mandrake.com> 1.2.5.2-1mdk
- 1.2.5.2
- cosmetics
- don't rm -rf %{buildroot} at the beginning of %%prep
- no .bz2 ending for man pages in file list
- fix typo in Fortran interface for MPI_Wtime (P4)
- Fix to the MPI-IO Fortran interface (P5)
- work around rsh test that might stall (P6)
- fix unpackaged files
- fix permissions for docs

* Tue Jan 21 2003  <erwan@no.mandrakesoft.com> 1.2.5-1mdk
- New version

* Thu Jan 16 2003 Erwan Velu <erwan@mandrakesoft.com> 1.2.4-31mdk
- fixing missed wrong requires for gcc

* Thu Jan 16 2003 Erwan Velu <erwan@mandrakesoft.com> 1.2.4-30mdk
- Rebuild for new Glibc
- Changing gcc requires

* Thu Dec 05 2002 Clic-dev <clic-dev-public@mandrakesoft.com> 1.2.4-29mdk
- Fixing wrong source format (thx to Gotz Waschk)

* Thu Nov 21 2002 Clic-dev <clic-dev-public@mandrakesoft.com> 1.2.4-28mdk
- Adding missing files
- Changing default documentation paths

* Wed Nov 20 2002 Clic-dev <clic-dev-public@mandrakesoft.com> 1.2.4-27mdk
- Removing lam conflict

* Thu Oct 10 2002 Clic-dev <clic-dev-public@mandrakesoft.com> 1.2.4-26mdk
- Fixing f77 compilation problem (libmpichfarg)

* Thu Oct 10 2002 Clic-dev <clic-dev-public@mandrakesoft.com> 1.2.4-25mdk
- Switching back to ch_p4 because ch_p4mpd doesn't support SMP nodes
- Switching back traceback 

* Wed Oct 09 2002 Clic-dev <clic-dev-public@mandrakesoft.com> 1.2.4-24mdk
- Applying official cumulative patch (7073, 7090, 7096, 7201, 7187, 7265, 7276)

* Tue Oct 08 2002 Erwan Velu <erwan@mandrakesoft.com> 1.2.4-23mdk
- Enable traceback option
- Switching from ch_p4 to ch_p4mpd
- Fixing (again) libpmpich problems

* Mon Aug 26 2002 Erwan Velu <erwan@mandrakesoft.com> 1.2.4-22mdk
- Re-adding mpi user
- Applying officials mpich patches
- Fixing buildrequires
- Enable debug for TotalView
- Separting mpi and pmpi libs
- Using -soft tag (avoid install mpich to build mpich)

* Thu Aug 08 2002 Antoine Ginies <aginies@mandrakesoft.com> 1.2.4-21mdk
- correct requires (thx Goetz Waschk)
- remove mpi user

* Tue Aug 06 2002 Antoine Ginies <aginies@mandrakesoft.com> 1.2.4-20mdk
- build with gcc 3.2

* Wed Jul 10 2002 Erwan Velu <erwan@mandrakesoft.com> 1.2.4-19mdk
- Changing exports from /etc/profile to /etc/bashc

* Tue Jul 09 2002 Erwan Velu <erwan@mandrakesoft.com> 1.2.4-18mdk
- Changing gcc requires to 2.96

* Tue Jul 09 2002 Erwan Velu <erwan@mandrakesoft.com> 1.2.4-17mdk
- Fixing MPICH_INCLUDE_PROFLIB problem in mpicc,mpiCC,mpicxx, mpif90 and mpif77

* Sat Jul 06 2002 Erwan Velu <erwan@mandrakesoft.com> 1.2.4-16mdk
- Suse merge
- Removing libpmpi.so.*
- Spliting libs in sub packages

* Sat Jul 06 2002 Erwan Velu <erwan@mandrakesoft.com> 1.2.4-15mdk
- Adding pmpi lib !

* Sat Jul 06 2002 Erwan Velu <erwan@mandrakesoft.com> 1.2.4-14mdk
- Fixing specfile for building & installing lib*.so

* Thu Jul 04 2002 Erwan Velu <erwan@mandrakesoft.com> 1.2.4-13mdk
- Removing bashrc & bash profile
- Moving testmpi.mpich in docdir

* Tue Jun 25 2002 Antoine Ginies <aginies@mandrakesoft.com> 1.2.4-12mdk
- adjust environement variable in /etc/profile

* Mon Jun 17 2002 Erwan Velu <erwan@mandrakesoft.com> 1.2.4-11mdk
- Adding noreplace on configuration files
- Removing building hostname on machines.LINUX

* Thu Jun 06 2002 Erwan Velu <erwan@mandrakesoft.com> 1.2.4-10mdk
- Setting mpi user id
* Wed Jun 05 2002 Erwan Velu <erwan@mandrakesoft.com> 1.2.4-9mdk
- Fixing typo in .bashrc of mpi user

* Tue Jun 04 2002 Erwan Velu <erwan@mandrakesoft.com> 1.2.4-8mdk
- Fixing wrong perm on sample script
- Using another sample script program

* Tue Jun 04 2002 Erwan Velu <erwan@mandrakesoft.com> 1.2.4-7mdk
- Removing gcc require on main mpich package
- Removing virtual Mpi provide

* Mon Jun 03 2002 Erwan Velu <erwan@mandrakesoft.com> 1.2.4-6mdk
- Fixing stupid friday mistake

* Fri May 31 2002 Erwan Velu <erwan@mandrakesoft.com> 1.2.4-5mdk
- Adding hello world sample mpi test program
- Adding ch_p4 option 

* Thu May 30 2002 Erwan Velu <erwan@mandrakesoft.com> 1.2.4-4mdk
- Adding /usr/adm for serv_p4 process
- Adding MPIRUN_HOME in default environment of mpi user

* Tue May 28 2002 Erwan Velu <erwan@mandrakesoft.com> 1.2.4-3mdk
- Adding more conflicts with lam

* Fri May 24 2002 Erwan Velu <erwan@mandrakesoft.com> 1.2.4-2mdk
- Provides virtual Mpi
- Fixing spec file

* Wed May 22 2002 Erwan Velu <erwan@mandrakesoft.com> 1.2.4-1mdk
- New release
- Bug-fix and improved-SMP performance release
- Other new features include better support for Intel compilers, particularly for IA64 Linux,
better support for various Fortran compilers, and some fixes for rare race conditions in the ch_p4 device.

* Wed May 22 2002 Erwan Velu <erwan@mandrakesoft.com> 1.2.2.2-7mdk
- Fixing home dir for MPI user
- Gcc 3.1 build

* Tue Apr 23 2002 Erwan Velu <erwan@mandrakesoft.com> 1.2.2.2-6mdk
- Fixing stupid places of man pages
- Fixing forgoten dependencies
- Adding rhosts example and warnings
- Adding MPI user

* Fri Apr 12 2002 Erwan Velu <erwan@mandrakesoft.com> 1.2.2.2-5mdk
- Fixing stupid things

* Fri Nov 23 2001 Ludovic Francois <lfrancois@mandrakesoft.com> 1.2.2.2-4mdk
- Removed unresolved dependencies

* Mon Nov 19 2001 Ludovic Francois <lfrancois@mandrakesoft.com> 1.2.2.2-3mdk
- Added sub packages mpich-doc mpicc mpic++ mpif77

* Tue Oct 25 2001 Ludovic Francois <lfrancois@mandrakesoft.com> 1.2.2.2-2mdk
- Rebuild for rpmlint

* Fri Oct 12 2001 Ludovic Francois <lfrancois@mandrakesoft.com> 1.2.2.2-1mdk
- Mpich package build for the first time.
